@@ -11,7 +11,10 @@ Attributes:
     logger: Logger for debug and messages.
 
 '''
-from __future__ import print_function
+try:
+    from .version import VERSION
+except ImportError:
+    VERSION = 'git'
 
 import gettext
 import logging
@@ -40,7 +43,7 @@ except (ImportError, AttributeError):
 APPID = 'org.debian.experimental.' + PACKAGE
 INFO = {
     'program_name': 'G Alternatives',
-    'version': '1.0.7',
+    'version': VERSION,
     'comments': _('A tool to help the administrator select which programs '
                   'provide specific services for the user by default.'),
     'license_type': 'GPL_2_0',
